Contributors
============

Development & Technical Support
-------------------------------

-   **Thomas Mansencal**, *Visual Effects Artist @ Weta Digital*

    Project coordination, overall development.

-   **Michael Mauderer**, *HCI Researcher @ University of Dundee*

    Colour appearance models, overall development.

-   **Michael Parsons**, *Colour Scientist @ The Moving Picture Company*

    Continuous technical support.

-   **Nick Shaw**, *Workflow Consultant @ Antler Post*

    YCbCr Colour Encoding, RED Colourspaces Derivation.

-   **Luke Canavan**

    Colour Quality Scale, Luminous Flux.

-   **Sean Cooper**, *Colour Scientist*

    Technical support.

-   **Kevin Wheatley**, *Head of Imaging @ Framestore*

    Technical support.

-   **Katherine Crowson**

    CIECAM02 improvements, technical support.

-   **Ofek Lev**

    Documentation improvements.

-   **Katrin Leinweber**

    Documentation improvements.

-   **Jean D. Vandenberg**, *Colour Scientist @ The Walt Disney Studios*

    Technical support.

Acknowledgements
----------------
-   **Steve Agland**, *Supervising Lighting Technical Director @ Animal Logic*

    Technical support.

-   **Tim Borer**, *Lead Engineer @ BBC Research & Development*

    *ITU-R BT.2100* technical support.

-   **Paul Centore**, *Mathematician & Colour Scientist*

    Matlab *Munsell Renotation System* implementation.

-   **Scott Dyer**, *Image Engineering @ Academy of Motion Picture Arts and Sciences*

    *ACES RGB IDT* technical support.

-   **Mark D. Fairchild**, *Director @ Munsell Color Science Lab, Director @ Program of Color Science*

    Technical support.

-   **Alex Forsythe**, *Image Engineering Manager @ Academy of Motion Picture Arts and Sciences*

    *ACES RGB IDT* technical support.

-   **Joseph Goldstone**, *Image Science Engineer @ ARRI*

    Technical support.

-   **Yoshi Ohno**, *Mathematician & Colour Scientist*

    *Ohno (2013)* correlated colour temperature calculation technical support.

-   **Charles Poynton**, *Mathematician & Colour Scientist*

    Technical support.

Special Mentions
----------------

-   **Aurélia Sellier**, *FX Production Coordinator @ Weta Digital*

Issues & Discussions
--------------------

-   Albert Szostkiewicz
-   Christophe Go
-   Giuseppe Di Guglielmo
-   Iman Sajedian
-   Marie Meyer
-   Max Marrone
-   Michal Krompiec
-   Nick Porcino
-   Nick Spiker
-   Ryan Bass
-   Vishal Vashistha
-   Vlad Enache
-   @Ampersandme
-   @awehring
-   @brandondube
-   @briend
-   @cclauss
-   @Chandler
-   @codycuellar
-   @Edwardlin-zlt
-   @eyeforcolor
-   @fangjy88
-   @Floschoe
-   @foutoucour
-   @habemus-papadum
-   @henczati
-   @iCagarro
-   @iinnovations
-   @jaguarondi
-   @KOLANICH
-   @Kunkka1988
-   @Legendin
-   @lensz
-   @naavis
-   @nschloe
-   @peteroupc
-   @Queuecumber
-   @Rob-Welch
-   @robbuckley
-   @Ron024
-   @shanest
-   @sobotka
-   @stakemura
-   @tashdor
-   @TFiFiE
-   @tingeman
-   @totyped
-   @Willingo
-   @zachlewis

About
-----

| **Colour** by Colour Developers - 2013-2019
| Copyright © 2013-2019 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`_
| This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
| `http://github.com/colour-science/colour <http://github.com/colour-science/colour>`_
